
/* verify.c */

#include <err.h>
#include <string.h>

#include <abac.h>
#include "creddy_common.h"

int debug=0;

// verify can only valiate that the issuer and the attribute credential
// are still valid currently and the issuer's keyid is the same as that
// of the signing issuer id of the attribute credential
static void _validate(abac_attribute_t *subjec_cert, abac_id_t *cert);

void verify_main(options_t *opts) {
    if (opts->cert == NULL)
        usage(opts);

    abac_id_t *issuer_id = abac_id_from_file(opts->cert);
    if (issuer_id == NULL)
        errx(1, "Can't load issuer cert from %s", opts->cert);
    if (opts->attrcert != NULL) {
        abac_list_t *attr_list = abac_attribute_certs_from_file(opts->attrcert);
        abac_attribute_t *subject_attr=NULL;
        abac_list_foreach(attr_list, subject_attr,
            _validate(subject_attr, issuer_id);
            abac_attribute_free(subject_attr);
        );
        abac_list_free(attr_list);
    } 

    abac_id_free(issuer_id);

}

static void _validate(abac_attribute_t *attr, abac_id_t *issuer)
{
    // checking for matching principal keyid
    char *prin=abac_attribute_get_principal(attr);
    char *keyid=abac_id_keyid(issuer);
    if(strcmp(prin,keyid) != 0)
        puts("issuer and attribute cert have mismatched principals\n");
        else puts("issuer and attribute cert have matching principals\n");
    free(prin);

    if(!abac_id_still_valid(issuer))
        puts("issuer cert not valid now");
        else puts("issuer cert still valid");

    if(!abac_attribute_still_valid(attr))
        puts("attribute cert not valid now");
        else puts("attribute cert still valid");
}
